# EC-Earth_patch

EC-Earth is a global coupled climate model. It is developed by a consortium of European research institutions.
The goal of this project is to adapt this model for our needs in TECLIM: install, run management, etc.

### Important Notes

**YOU MUST HAVE YOUR `~/.ssh/id_rsa.ceci.pub` FILE BEFORE STARTING TO WORK WITH GIT ON ZENOBE**.

## Install

First, clone the `pbarriat/ecearth_patch` repository:
```bash
mkdir -p ~/modeles/ecearth
cd ~/modeles/ecearth
git clone https://gogs.elic.ucl.ac.be/TECLIM/ecearth_patch.git
```

Now, update your shell startup script (`~/.bashrc`) to add ecearth globals variables to your environment. 

### Zenobe

```bash
configure_ecearth()
{
  export EC_DEP=/projects/acad/ecearth/opt
  if [ -f $EC_DEP/modules.load ]; then
    source $EC_DEP/modules.load
  fi
}
```

### Lemaitre3

```bash
configure_ecearth()
{
  module purge
  module load 2016a netCDF-Fortran/4.4.4-intel-2016a grib_api/1.16.0-intel-2016a openjpeg/1.5.2-intel-2016a
}
```

### Source code

Then, checkout the EC-Earth SVN repository. Five alternatives:
```bash
cd ~/modeles/ecearth

svn co https://svn.ec-earth.org/ecearth3/tags/3.2.2 ecearth_3.2.2

svn co https://svn.ec-earth.org/ecearth3/tags/3.2.3 ecearth_3.2.3

svn co https://svn.ec-earth.org/ecearth3/tags/3.3.0 ecearth_3.3.0

svn co https://svn.ec-earth.org/ecearth3/tags/3.3.3.2 ecearth_3.3.3.2

svn co https://svn.ec-earth.org/ecearth3/branches/projects/primavera ecearth_primavera

svn co https://svn.ec-earth.org/ecearth3/trunk ecearth_trunk
```

Final step, go to the `ecearth_patch` repository and run the `install.sh` script:
```
cd ~/modeles/ecearth/ecearth_patch
./install.sh
```

## Compile

**YOU MUST COMPILE ON frontal1 for ZENOBE (ssh frontal1 from zenobe)**

* Go to `ecearth sources` and create all the Makefile's with corresponding configuration:

```bash
TAG=3.3.3.2
CONF=zenobe

configure_ecearth
cd ~/modeles/ecearth/ecearth_$TAG/sources
./util/ec-conf/ec-conf -p $CONF-intelmpi config-build.xml
```

* Compile **oasis3**:

```bash
cd oasis3-mct/util/make_dir
make BUILD_ARCH=ecconf -f TopMakefileOasis3
cd ../../..
```

* Compile **IFS**:

```bash
cd ifs-36r4
./makeifs -j 4
cd ..
```

* Compile **xios-2**:

```bash
cd xios-2
./make_xios --prod --arch ecconf --use_oasis oasis3_mct --netcdf_lib netcdf4_par -j 4
cd ..
```

* Compile **NEMO**:

```bash
cd nemo-3.6/CONFIG
./makenemo -n ORCA1L75_LIM3 -m ecconf -j4
cd ../..
```

* Compile **runoff-mapper**:

```bash
cd runoff-mapper/src
make
cd ../..
```

**Primavera context**:

* Compile **amip-forcing**:

```bash
cd amip-forcing/src
make
cd ../..
```

* Configure **ELPiN**:

```bash
cd util/ELPiN
mkdir bathymetries
ln -s /scratch/ucl/elic/pbarriat/DATA/EC-EARTH/nemo/initial/ORCA1L75/bathy_meter.nc bathymetries/nemo_bathy_meter_ORCA1.nc
ln -s /scratch/ucl/elic/pbarriat/DATA/EC-EARTH/nemo/initial/ORCA1L75/bathy_meter.nc bathymetries/nemo_bathy_meter_ORCA1.nc
sed -i 's/ORCA025/ORCA1/g' src/namelist_mpp
./Configure
cd ../..
```

## Run

```bash
cd ~/modeles/ecearth/ecearth_$TAG/runtime/classic
../../sources/util/ec-conf/ec-conf -p $CONF config-run.xml
vi ece-esm.sh
qsub (or sbatch) ece-esm.sh
qstat (or squeue) -u $USER
```

## Benchmarks

### Lemaitre3

| XIOS | NEMO | IFS | Runoff | WTIME per YEAR | #CORES |
| ---- | ---- | --- | ------ | -------------- | ------ |
| 1    |   8  |  14 |    1   |                |    24  |
| 1    |   4  |  18 |    1   |    **32h**     |    24  |
| 1    |  64  |  78 |    1   |    **3h56**    |   144  |
| 6    |  64  | 288 |    1   |                |   360  |

### Zenobe

| XIOS | NEMO | IFS | Runoff | WTIME per YEAR | #CORES |
| ---- | ---- | --- | ------ | -------------- | ------ |
| 1    |  64  |  78 |    1   |      **5h**    |   144  |
| 22   |  72  | 288 |    1   |    **3h15**    |   384  |
| 1    |  86  | 320 |    1   |    **2h55**    |   408  |
| 22   | 144  | 432 |    1   |                |   600  |

## Contributors

- ELIC members [@pbarriat](https://gogs.elic.ucl.ac.be/pbarriat)

## License

This project is under the Creative Commons CC0 1.0 Universal License. See the [LICENSE](https://gogs.elic.ucl.ac.be/TECLIM/LOVECLIM/src/master/LICENSE) file for the full license text.
